This function scans the data frame and creates a mapping of family IDs to the corresponding parent IDs.
Arguments
- df_temp
A data frame produced by
readGedcom().- mom_sex
Character string indicating the value of sex that corresponds to mothers (default "F").
- dad_sex
Character string indicating the value of sex that corresponds to fathers (default "M").